@@ -138,6 +138,8 @@ struct vzctl_snapshot_param {
 	char *guid;
 	char *name;
 	char *desc;
+#define SNAPSHOT_SKIP_SUSPEND	1 << 1
+	int flags;
 };
 
 struct vps_param {
@@ -165,12 +167,6 @@ typedef struct vps_param vps_param;
 int vps_setup_res(vps_handler *h, envid_t veid, dist_actions *actions,
 	fs_param *fs, vps_param *param, int vps_state, skipFlags skip,
 	struct mod_action *action);
-int setup_resource_management(vps_handler *h, envid_t veid, vps_res *res);
 int need_configure(vps_res *res);
 
-/* Second-level quota */
-struct setup_env_quota_param;
-int fill_2quota_param(struct setup_env_quota_param *p,
-		const char *ve_private, const char *ve_root);
-
 #endif
