@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
+ *  Copyright (C) 2000-2012, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,7 +38,13 @@ typedef enum {
 	ACTION_RESTORE,
 	ACTION_QUOTAON,
 	ACTION_QUOTAOFF,
-	ACTION_QUOTAINIT
+	ACTION_QUOTAINIT,
+	ACTION_CONSOLE,
+	ACTION_CONVERT,
+	ACTION_SNAPSHOT_CREATE,
+	ACTION_SNAPSHOT_SWITCH,
+	ACTION_SNAPSHOT_DELETE,
+	ACTION_SNAPSHOT_LIST,
 } act_t;
 
 /* default cpu units values */
