@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
+ *  Copyright (C) 2000-2009, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,7 +25,8 @@ struct feature_s {
 };
 
 struct feature_s *find_feature(const char *name);
-void features_mask2str(unsigned long long, unsigned long long, char *, int);
+
+void features_mask2str(unsigned long long mask, unsigned long long known,
+		const char *delim, char *buf, int len);
 
 #endif //_VZFEATURES_H_
-
