@@ -47,15 +47,15 @@
 
 static int setup_hardlink_dir(const char *mntdir, int cpt_fd);
 
-int cpt_cmd(vps_handler *h, envid_t veid, int action, cpt_param *param,
-	vps_param *vps_p)
+int cpt_cmd(vps_handler *h, envid_t veid, const char *root,
+		int action, int cmd, unsigned int ctx)
 {
 	int fd;
 	int err, ret = 0;
 	const char *file;
 
 	if (!vps_is_run(h, veid)) {
-		logger(0, 0, "Container is not running");
+		logger(-1, 0, "Container is not running");
 		return VZ_VE_NOT_RUNNING;
 	}
 	if (action == CMD_CHKPNT) {
@@ -76,11 +76,11 @@ int cpt_cmd(vps_handler *h, envid_t veid, int action, cpt_param *param,
 			logger(-1, errno, "Unable to open %s", file);
 		return err;
 	}
-	if ((ret = ioctl(fd, CPT_JOIN_CONTEXT, param->ctx ? : veid)) < 0) {
-		logger(-1, errno, "Can not join cpt context %d", param->ctx);
+	if ((ret = ioctl(fd, CPT_JOIN_CONTEXT, ctx ? : veid)) < 0) {
+		logger(-1, errno, "Can not join cpt context %d", ctx ? : veid);
 		goto err;
 	}
-	switch (param->cmd) {
+	switch (cmd) {
 	case CMD_KILL:
 		logger(0, 0, "Killing...");
 		if ((ret = ioctl(fd, CPT_KILL, 0)) < 0) {
@@ -90,20 +90,14 @@ int cpt_cmd(vps_handler *h, envid_t veid, int action, cpt_param *param,
 		break;
 	case CMD_RESUME:
 		logger(0, 0, "Resuming...");
-		clean_hardlink_dir(vps_p->res.fs.root);
+		clean_hardlink_dir(root);
 		if ((ret = ioctl(fd, CPT_RESUME, 0)) < 0) {
 			logger(-1, errno, "Can not resume container");
 			goto err;
 		}
-		if (action == CMD_CHKPNT) {
-			/* restore arp/routing cleared on dump stage */
-			run_net_script(veid, ADD, &vps_p->res.net.ip,
-				STATE_RUNNING,
-				vps_p->res.net.skip_arpdetect);
-		}
 		break;
 	}
-	if (!param->ctx) {
+	if (!ctx) {
 		logger(2, 0, "\tput context");
 		if ((ret = ioctl(fd, CPT_PUT_CONTEXT, 0)) < 0) {
 			logger(-1, errno, "Can not put context");
@@ -191,13 +185,27 @@ err_out:
 	return VZ_CHKPNT_ERROR;
 }
 
-int vps_chkpnt(vps_handler *h, envid_t veid, vps_param *vps_p, int cmd,
-	cpt_param *param)
+#define GET_DUMP_FILE(req_cmd)							\
+do {										\
+	dumpfile = param->dumpfile;						\
+	if (dumpfile == NULL) {							\
+		if (cmd == req_cmd) {						\
+			logger(-1,  0, "Error: dumpfile is not specified");	\
+			goto err;						\
+		}								\
+		get_dump_file(veid, param->dumpdir, buf, sizeof(buf));		\
+		dumpfile = buf;							\
+	}									\
+} while (0)
+
+int vps_chkpnt(vps_handler *h, envid_t veid, const fs_param *fs,
+		int cmd, cpt_param *param)
 {
 	int dump_fd = -1;
-	char dumpfile[PATH_LEN];
+	char buf[PATH_LEN];
+	const char *dumpfile = NULL;
 	int cpt_fd, pid, ret;
-	const char *root = vps_p->res.fs.root;
+	const char *root = fs->root;
 
 	ret = VZ_CHKPNT_ERROR;
 	if (root == NULL) {
@@ -219,20 +227,12 @@ int vps_chkpnt(vps_handler *h, envid_t veid, vps_param *vps_p, int cmd,
 		return VZ_CHKPNT_ERROR;
 	}
 	if ((cmd == CMD_CHKPNT || cmd == CMD_DUMP)) {
-		if (param->dumpfile == NULL) {
-			if (cmd == CMD_DUMP) {
-				logger(-1,  0, "Error: dumpfile is not"
-					" specified.");
-				goto err;
-			}
-			get_dump_file(veid, vps_p->res.cpt.dumpdir,
-					dumpfile, sizeof(dumpfile));
-		}
-		dump_fd = open(param->dumpfile ? : dumpfile,
-			O_CREAT|O_TRUNC|O_RDWR, 0600);
+		GET_DUMP_FILE(CMD_DUMP);
+		make_dir(dumpfile, 0);
+		dump_fd = open(dumpfile, O_CREAT|O_TRUNC|O_RDWR, 0600);
 		if (dump_fd < 0) {
 			logger(-1, errno, "Can not create dump file %s",
-				param->dumpfile ? : dumpfile);
+					dumpfile);
 			goto err;
 		}
 	}
@@ -283,21 +283,15 @@ int vps_chkpnt(vps_handler *h, envid_t veid, vps_param *vps_p, int cmd,
 	ret = env_wait(pid);
 	if (ret)
 		goto err;
-	if (cmd == CMD_CHKPNT || cmd == CMD_DUMP) {
-		/* Clear CT network configuration */
-		run_net_script(veid, DEL, &vps_p->res.net.ip, STATE_RUNNING,
-			vps_p->res.net.skip_arpdetect);
-		if (cmd == CMD_CHKPNT)
-			vps_umount(h, veid, root, 0);
-	}
 	ret = 0;
-	logger(0, 0, "Checkpointing completed succesfully");
+	logger(0, 0, "Checkpointing completed successfully");
 err:
 	if (ret) {
 		ret = VZ_CHKPNT_ERROR;
 		logger(-1, 0, "Checkpointing failed");
 		if (cmd == CMD_CHKPNT || cmd == CMD_DUMP)
-			unlink(param->dumpfile ? : dumpfile);
+			if (dumpfile)
+				unlink(dumpfile);
 	}
 	if (dump_fd != -1)
 		close(dump_fd);
@@ -401,12 +395,13 @@ int vps_restore(vps_handler *h, envid_t veid, vps_param *vps_p, int cmd,
 {
 	int ret, rst_fd;
 	int dump_fd = -1;
-	char dumpfile[PATH_LEN];
+	char buf[PATH_LEN];
+	const char *dumpfile = NULL;
 
 	if (vps_is_run(h, veid)) {
 		logger(-1, 0, "Unable to perform restore: "
 			"container already running");
-		return VZ_VE_NOT_RUNNING;
+		return VZ_VE_RUNNING;
 	}
 	logger(0, 0, "Restoring container ...");
 	ret = VZ_RESTORE_ERROR;
@@ -424,20 +419,11 @@ int vps_restore(vps_handler *h, envid_t veid, vps_param *vps_p, int cmd,
 			goto err;
 		}
 	}
-	if (param->dumpfile == NULL) {
-		if (cmd == CMD_UNDUMP) {
-			logger(-1, 0, "Error: dumpfile is not specified");
-			goto err;
-		}
-
-			get_dump_file(veid, vps_p->res.cpt.dumpdir,
-					dumpfile, sizeof(dumpfile));
-	}
+	GET_DUMP_FILE(CMD_UNDUMP);
 	if (cmd == CMD_RESTORE || cmd == CMD_UNDUMP) {
-		dump_fd = open(param->dumpfile ? : dumpfile, O_RDONLY);
+		dump_fd = open(dumpfile, O_RDONLY);
 		if (dump_fd < 0) {
-			logger(-1, errno, "Unable to open %s",
-				param->dumpfile ? : dumpfile);
+			logger(-1, errno, "Unable to open %s", dumpfile);
 			goto err;
 		}
 	}
@@ -453,25 +439,16 @@ int vps_restore(vps_handler *h, envid_t veid, vps_param *vps_p, int cmd,
 		NULL, restore_fn, param);
 	if (ret)
 		goto err;
-	/* Restore second-level quota links & quota device */
-	if ((cmd == CMD_RESTORE || cmd == CMD_UNDUMP) &&
-		vps_p->res.dq.ugidlimit != NULL &&
-		*vps_p->res.dq.ugidlimit != 0)
-	{
-		logger(0, 0, "Restore second-level quota");
-		if (vps_execFn(h, veid, vps_p->res.fs.root, mk_quota_link, NULL,
-			VE_SKIPLOCK))
-		{
-			logger(-1, 0, "Warning: restoring second-level "
-					"quota links failed");
-		}
-	}
 err:
 	close(rst_fd);
 	if (dump_fd != -1)
 		close(dump_fd);
-	if (!ret)
-		logger(0, 0, "Restoring completed succesfully");
+	if (!ret) {
+		logger(0, 0, "Restoring completed successfully");
+		if (cmd == CMD_RESTORE)
+			if (dumpfile)
+				unlink(dumpfile);
+	}
 	return ret;
 }
 
