@@ -80,7 +80,7 @@ static int check_param(struct ub_struct *param, int log)
 }
 
 #define SET_MES(val)	logger(0, 0, "set to %lu", val);
-#define SET2_MES(val1, val2) logger(0, 0,"set to %lu:%lu", val1, val2);
+#define SET2_MES(val1, val2) logger(0, 0, "set to %lu:%lu", val1, val2);
 
 /** Validate vswap config
  * Current ideas are:
@@ -546,7 +546,7 @@ if (ub->name != NULL) {							\
 		if (!recover) ret = 1;
 //		if (!ask) fprintf(stderr, "\n");
 	} else if (ub->othersockbuf[0] < val1) {
-		logger(-1, 0,"Recommendation: othersockbuf.bar should be >"
+		logger(-1, 0, "Recommendation: othersockbuf.bar should be >"
 				" %lu (currently, %lu)", val1,
 				ub->othersockbuf[0]);
 		if (ask || recover) {
@@ -675,41 +675,3 @@ int calc_ve_commitment(struct ub_struct *param, struct CRusage *rusage,
 		rusage->alloc_mem_max_lim /= mem->ram;
 	return 0;
 }
-
-void inc_rusage(struct CRusage *rusagetotal, struct CRusage *rusage)
-{
-	if (rusagetotal == NULL || rusage == NULL)
-		return;
-	rusagetotal->low_mem += rusage->low_mem;
-	rusagetotal->total_ram += rusage->total_ram;
-	rusagetotal->mem_swap += rusage->mem_swap;
-	rusagetotal->alloc_mem += rusage->alloc_mem;
-	rusagetotal->alloc_mem_lim += rusage->alloc_mem_lim;
-	if (rusage->alloc_mem_max_lim > rusagetotal->alloc_mem_max_lim)
-		rusagetotal->alloc_mem_max_lim = rusage->alloc_mem_max_lim;
-}
-
-
-void shift_ubs_param(struct ub_struct *param)
-{
-#define SHIFTPARAM(name)						\
-if (param->name != NULL) {						\
-	param->name[0] = param->name[1];				\
-	param->name[1] = param->name[2];				\
-}
-	SHIFTPARAM(numproc);
-	SHIFTPARAM(numtcpsock);
-	SHIFTPARAM(numothersock);
-	SHIFTPARAM(oomguarpages)
-	SHIFTPARAM(vmguarpages);
-	SHIFTPARAM(kmemsize);
-	SHIFTPARAM(tcpsndbuf);
-	SHIFTPARAM(tcprcvbuf);
-	SHIFTPARAM(othersockbuf);
-	SHIFTPARAM(dgramrcvbuf);
-	SHIFTPARAM(privvmpages);
-	SHIFTPARAM(numfile);
-	SHIFTPARAM(dcachesize);
-	SHIFTPARAM(physpages)
-	SHIFTPARAM(numpty)
-}
